@@ -30,31 +30,31 @@
 #include "simpletlv.h"
 #include "common.h"
 
-static unsigned char cac_aca_aid[] = {
+static const unsigned char cac_aca_aid[] = {
     0xa0, 0x00, 0x00, 0x00, 0x79, 0x03, 0x00 };
-static unsigned char cac_ccc_aid[] = {
+static const unsigned char cac_ccc_aid[] = {
     0xa0, 0x00, 0x00, 0x01, 0x16, 0xDB, 0x00 };
-static unsigned char cac_02fb_aid[] = {
+static const unsigned char cac_02fb_aid[] = {
     0xa0, 0x00, 0x00, 0x00, 0x79, 0x02, 0xFB };
-static unsigned char cac_1201_aid[] = {
+static const unsigned char cac_1201_aid[] = {
     0xa0, 0x00, 0x00, 0x00, 0x79, 0x12, 0x01 };
-static unsigned char cac_1202_aid[] = {
+static const unsigned char cac_1202_aid[] = {
     0xa0, 0x00, 0x00, 0x00, 0x79, 0x12, 0x02 };
-static unsigned char cac_02f0_aid[] = {
+static const unsigned char cac_02f0_aid[] = {
     0xa0, 0x00, 0x00, 0x00, 0x79, 0x02, 0xF0 };
-static unsigned char cac_02f1_aid[] = {
+static const unsigned char cac_02f1_aid[] = {
     0xa0, 0x00, 0x00, 0x00, 0x79, 0x02, 0xF1 };
-static unsigned char cac_02f2_aid[] = {
+static const unsigned char cac_02f2_aid[] = {
     0xa0, 0x00, 0x00, 0x00, 0x79, 0x02, 0xF2 };
-static unsigned char cac_access_control_aid[] = {
+static const unsigned char cac_access_control_aid[] = {
     0xa0, 0x00, 0x00, 0x01, 0x16, 0x30, 0x00 };
-static unsigned char cac_pki_certificate_aid[] = {
+static const unsigned char cac_pki_certificate_aid[] = {
     0xa0, 0x00, 0x00, 0x00, 0x79, 0x02, 0xFE };
-static unsigned char cac_pki_credential_aid[] = {
+static const unsigned char cac_pki_credential_aid[] = {
     0xa0, 0x00, 0x00, 0x00, 0x79, 0x02, 0xFD };
-static unsigned char cac_person_instance_aid[] = {
+static const unsigned char cac_person_instance_aid[] = {
     0xa0, 0x00, 0x00, 0x00, 0x79, 0x02, 0x00 };
-static unsigned char cac_personnel_aid[] = {
+static const unsigned char cac_personnel_aid[] = {
     0xa0, 0x00, 0x00, 0x00, 0x79, 0x02, 0x01 };
 
 
@@ -264,7 +264,7 @@ cac_common_process_apdu(VCard *card, VCardAPDU *apdu, VCardResponse **response)
     switch (apdu->a_ins) {
     case CAC_GET_PROPERTIES:
         /* 5.3.3.4: Get Properties APDU */
-        assert(applet_private);
+        g_assert(applet_private);
 
         if (apdu->a_p2 != 0x00) {
             /* P2 needs to be 0x00 */
@@ -330,7 +330,7 @@ cac_common_process_apdu(VCard *card, VCardAPDU *apdu, VCardResponse **response)
             break;
         }
 
-        assert(applet_private);
+        g_assert(applet_private);
 
         /* handle file id setting */
         if (apdu->a_Lc != 2) {
@@ -398,7 +398,7 @@ cac_common_process_apdu_read(VCard *card, VCardAPDU *apdu,
 
         /* P1 | P2 defines offset to read from */
         offset = (apdu->a_p1 << 8) | apdu->a_p2;
-        g_debug("%s: Reqested offset: %d bytes", __func__, offset);
+        g_debug("%s: Requested offset: %d bytes", __func__, offset);
 
         /* First byte selects TAG+LEN or VALUE buffer */
         switch (apdu->a_body[0]) {
@@ -414,7 +414,7 @@ cac_common_process_apdu_read(VCard *card, VCardAPDU *apdu,
                         apdu->a_Le, VCARD7816_SW1_SUCCESS, 0);
             break;
         case CAC_FILE_TAG:
-            g_debug("%s: Reqested: %d bytes", __func__, size);
+            g_debug("%s: Requested: %d bytes", __func__, size);
             size = MIN(size, applet_private->tag_buffer_len - offset);
             if (size < 0) { /* Overrun returns (SW1=0x6A, SW2=0x86) */
                 *response = vcard_make_response(
@@ -460,7 +460,7 @@ cac_applet_pki_reset(VCard *card, int channel)
     VCardAppletPrivate *applet_private;
     CACPKIAppletData *pki_applet;
     applet_private = vcard_get_current_applet_private(card, channel);
-    assert(applet_private);
+    g_assert(applet_private);
     pki_applet = &(applet_private->u.pki_data);
 
     g_free(pki_applet->sign_buffer);
@@ -474,7 +474,7 @@ cac_applet_passthrough_reset(VCard *card, int channel)
 {
     VCardAppletPrivate *applet_private;
     applet_private = vcard_get_current_applet_private(card, channel);
-    assert(applet_private);
+    g_assert(applet_private);
 
     g_free(applet_private->tag_buffer);
     applet_private->tag_buffer = NULL;
@@ -498,7 +498,7 @@ cac_applet_pki_process_apdu(VCard *card, VCardAPDU *apdu,
     VCardStatus ret = VCARD_FAIL;
 
     applet_private = vcard_get_current_applet_private(card, apdu->a_channel);
-    assert(applet_private);
+    g_assert(applet_private);
     pki_applet = &(applet_private->u.pki_data);
 
     switch (apdu->a_ins) {
@@ -574,7 +574,7 @@ cac_applet_aca_process_apdu(VCard *card, VCardAPDU *apdu,
     int format;
 
     applet_private = vcard_get_current_applet_private(card, apdu->a_channel);
-    assert(applet_private);
+    g_assert(applet_private);
     aca_applet = &(applet_private->u.aca_data);
 
     switch (apdu->a_ins) {
@@ -713,7 +713,7 @@ cac_passthrough_container_process_apdu(VCard *card, VCardAPDU *apdu,
     VCardAppletPrivate *applet_private;
 
     applet_private = vcard_get_current_applet_private(card, apdu->a_channel);
-    assert(applet_private);
+    g_assert(applet_private);
     pt_applet = &(applet_private->u.pt_data);
 
     switch (apdu->a_ins) {
@@ -964,7 +964,7 @@ cac_new_pki_applet_private(int i, const unsigned char *cert,
         goto failure;
     }
     g_debug("%s: applet_private->tag_buffer = %s", __func__,
-        hex_dump(applet_private->tag_buffer, applet_private->tag_buffer_len, NULL, 0));
+        hex_dump(applet_private->tag_buffer, applet_private->tag_buffer_len));
 
     /* Value buffer */
     /* Ex:
@@ -981,7 +981,7 @@ cac_new_pki_applet_private(int i, const unsigned char *cert,
         goto failure;
     }
     g_debug("%s: applet_private->val_buffer = %s", __func__,
-        hex_dump(applet_private->val_buffer, applet_private->val_buffer_len, NULL, 0));
+        hex_dump(applet_private->val_buffer, applet_private->val_buffer_len));
 
     /* Inject Object ID */
     object_id[1] = i;
@@ -1681,7 +1681,7 @@ cac_new_ccc_applet_private(int cert_count)
     if (applet_private->tag_buffer_len == 0)
         goto failure;
     g_debug("%s: applet_private->tag_buffer = %s", __func__,
-        hex_dump(applet_private->tag_buffer, applet_private->tag_buffer_len, NULL, 0));
+        hex_dump(applet_private->tag_buffer, applet_private->tag_buffer_len));
 
     /* Value buffer */
     /* Ex:
@@ -1723,7 +1723,7 @@ cac_new_ccc_applet_private(int cert_count)
     if (applet_private->val_buffer_len == 0)
         goto failure;
     g_debug("%s: applet_private->val_buffer = %s", __func__,
-        hex_dump(applet_private->val_buffer, applet_private->val_buffer_len, NULL, 0));
+        hex_dump(applet_private->val_buffer, applet_private->val_buffer_len));
 
     /* Inject Object ID */
     tv_object[0].value.value = object_id;
@@ -2022,7 +2022,7 @@ failure:
 
 static VCardAppletPrivate *
 cac_new_passthrough_applet_private(VCard *card, const char *label,
-                                   unsigned char *aid, unsigned int aid_len)
+                                   const unsigned char *aid, unsigned int aid_len)
 {
     CACPTAppletData *pt_applet_data;
     VCardAppletPrivate *applet_private;
@@ -2168,7 +2168,7 @@ failure:
 }
 
 static VCardApplet *
-cac_new_empty_applet(unsigned char *aid, unsigned int aid_len,
+cac_new_empty_applet(const unsigned char *aid, unsigned int aid_len,
                      unsigned char coids[][2], unsigned int coids_len)
 {
     VCardAppletPrivate *applet_private;
@@ -2200,7 +2200,7 @@ failure:
 
 static VCardApplet *
 cac_new_passthrough_applet(VCard *card, const char *label,
-                           unsigned char *aid, unsigned int aid_len)
+                           const unsigned char *aid, unsigned int aid_len)
 {
     VCardAppletPrivate *applet_private;
     VCardApplet *applet;
