@@ -15,10 +15,10 @@
 
 
 /* Global Platform Card Manager applet AID */
-static unsigned char gp_aid[] = {
+static const unsigned char gp_aid[] = {
     0xa0, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00 };
-/* Global Platfrom Card Manager response on select applet */
-static unsigned char gp_response[] = {
+/* Global Platform Card Manager response on select applet */
+static const unsigned char gp_response[] = {
     0x6F, 0x19, 0x84, 0x08, 0xA0, 0x00, 0x00, 0x00,
     0x03, 0x00, 0x00, 0x00, 0xA5, 0x0D, 0x9F, 0x6E,
     0x06, 0x12, 0x91, 0x51, 0x81, 0x01, 0x00, 0x9F,
@@ -61,7 +61,7 @@ vcard_response_set_status_bytes(VCardResponse *response,
  * set up everything but the resonse bytes.
  */
 VCardResponse *
-vcard_response_new_data(unsigned char *buf, int len)
+vcard_response_new_data(const unsigned char *buf, int len)
 {
     VCardResponse *new_response;
 
@@ -75,7 +75,7 @@ vcard_response_new_data(unsigned char *buf, int len)
 }
 
 static VCardResponse *
-vcard_init_buffer_response(VCard *card, unsigned char *buf, int len)
+vcard_init_buffer_response(VCard *card, const unsigned char *buf, int len)
 {
     VCardResponse *response;
     VCardBufferResponse *buffer_response;
@@ -102,7 +102,7 @@ vcard_init_buffer_response(VCard *card, unsigned char *buf, int len)
  * general buffer to hold results from APDU calls
  */
 VCardResponse *
-vcard_response_new(VCard *card, unsigned char *buf,
+vcard_response_new(VCard *card, const unsigned char *buf,
                    int len, int Le, vcard_7816_status_t status)
 {
     VCardResponse *new_response;
@@ -659,7 +659,7 @@ vcard7816_vm_process_apdu(VCard *card, VCardAPDU *apdu,
                 *response = vcard_response_new(card, gp_response,
                     sizeof(gp_response), apdu->a_Le, VCARD7816_STATUS_SUCCESS);
             } else {
-                static unsigned char fci_template[] = {
+                unsigned char fci_template[] = {
                     0x6F, 0x0B, 0x84, 0x07, 0xA0, 0x00, 0x00, 0x00,
                     0x79, 0x03, 0x00, 0xA5, 0x00};
                 /* with GSC-IS 2 applets, we do not need to return anything
@@ -669,7 +669,7 @@ vcard7816_vm_process_apdu(VCard *card, VCardAPDU *apdu,
                  * 6F 0B : FCI Template
                  *  84 07 : Application / file AID
                  *   A0 00 00 00 79 03 00
-                 *  A5 00 : Porprietary data
+                 *  A5 00 : Proprietary data
                  */
                 /* Insert the correct AID in the structure */
                 g_assert_cmpint(apdu->a_Lc, ==, 7);
@@ -754,7 +754,7 @@ vcard7816_vm_process_apdu(VCard *card, VCardAPDU *apdu,
     }
 
     /* response should have been set somewhere */
-    assert(*response != NULL);
+    g_assert(*response != NULL);
     return VCARD_DONE;
 }
 
@@ -795,7 +795,7 @@ vcard_process_apdu(VCard *card, VCardAPDU *apdu, VCardResponse **response)
         return vcard7816_vm_process_apdu(card, apdu, response);
     case VCARD_DIRECT:
         /* if we are type direct, then the applet should handle everything */
-        assert(!"VCARD_DIRECT: applet failure");
+        g_assert(!"VCARD_DIRECT: applet failure");
         break;
     default:
         g_warn_if_reached();
